==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnGroupDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebColumnDescription } from "./WebColumnDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebColumnGroupDescription = /*@__PURE__*/ (() => {
    class WebColumnGroupDescription extends WebColumnDescription {
        constructor() {
            super();
            this.cw = null;
            this.c0 = null;
        }
        get_type() {
            return "WebColumnGroup";
        }
        get children() {
            return this.cw;
        }
        set children(a) {
            this.cw = a;
            this.e("Children");
        }
        get collapsibleIndicatorTemplateRef() {
            return this.c0;
        }
        set collapsibleIndicatorTemplateRef(a) {
            this.c0 = a;
            this.e("CollapsibleIndicatorTemplateRef");
        }
    }
    WebColumnGroupDescription.$t = /*@__PURE__*/ markType(WebColumnGroupDescription, 'WebColumnGroupDescription', WebColumnDescription.$);
    WebColumnGroupDescription.__canMarshalByValue1 = true;
    WebColumnGroupDescription.__marshalByValueAlias1 = "ColumnGroup";
    return WebColumnGroupDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebColumnGroupDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { WebColumnDescription } from "./WebColumnDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebColumnGroupDescription = /*@__PURE__*/ (() => {
    class WebColumnGroupDescription extends WebColumnDescription {
        get_type() {
            return "WebColumnGroup";
        }
        constructor() {
            super();
            this.co = null;
            this.cr = false;
            this.cs = false;
            this.cw = null;
        }
        get children() {
            return this.co;
        }
        set children(a) {
            this.co = a;
            this.g("Children");
        }
        get collapsible() {
            return this.cr;
        }
        set collapsible(a) {
            this.cr = a;
            this.g("Collapsible");
        }
        get expanded() {
            return this.cs;
        }
        set expanded(a) {
            this.cs = a;
            this.g("Expanded");
        }
        get collapsibleIndicatorTemplateRef() {
            return this.cw;
        }
        set collapsibleIndicatorTemplateRef(a) {
            this.cw = a;
            this.g("CollapsibleIndicatorTemplateRef");
        }
    }
    WebColumnGroupDescription.$t = /*@__PURE__*/ markType(WebColumnGroupDescription, 'WebColumnGroupDescription', WebColumnDescription.$);
    WebColumnGroupDescription.__canMarshalByValue1 = true;
    WebColumnGroupDescription.__marshalByValueAlias1 = "ColumnGroup";
    return WebColumnGroupDescription;
})();
